@@ -167,11 +167,14 @@ class Data:
     # (package_name == value of cl_belong_pkg)
     cl_belong_pkg = {'mode':'r', 'hide':True}
 
+    # x11 resolution (1024x768 and etc)
+    os_x11_resolution = {'mode':'w','hide':True}
+
     # vertical resolution for X server
-    os_x11_height = {'mode':"w", 'hide':True}
+    os_x11_height = {'mode':"r", 'hide':True}
 
     # horizontal resolution for X server
-    os_x11_width = {'mode':"w", 'hide':True}
+    os_x11_width = {'mode':"r", 'hide':True}
 
     # the nearest standard size of image to current screen resolution
     os_x11_standart = {'hide':True}
